"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.migrationsLoader = void 0;
const core_1 = require("../core");
const logger = core_1.Logger.contextualize('MigrationsLoader');
/**
 * @internal
 * Run custom migrations that are find from the provided directory and stored in a `migrations` subdirectory.
 * @param migrationsOptions Any custom migration that implements MigrationInterface
 * @param dbConnection Database connection from medusa internal
 */
async function migrationsLoader(migrationsOptions, dbConnection) {
    logger.log('Registering migrations into the ORM connection');
    for (const migrationOptions of migrationsOptions) {
        dbConnection.migrations.push(new migrationOptions.metatype());
    }
    logger.log('Running migrations');
    await dbConnection.runMigrations().then((ranMigrations) => {
        for (const migration of ranMigrations) {
            logger.log('Migration applied - %s', migration.name);
        }
    });
}
exports.migrationsLoader = migrationsLoader;
//# sourceMappingURL=migrations.loader.js.map