"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var _TenantService_tenantRepository;
Object.defineProperty(exports, "__esModule", { value: true });
exports.TenantService = void 0;
const decorators_1 = require("../../decorators");
const typeorm_1 = require("typeorm");
const naming_strategy_1 = require("@medusajs/medusa/dist/utils/naming-strategy");
let TenantService = class TenantService {
    constructor(container, config) {
        this.container = container;
        this.config = config;
        _TenantService_tenantRepository.set(this, void 0);
        __classPrivateFieldSet(this, _TenantService_tenantRepository, container.tenantRepository, "f");
    }
    /**
     * Provide a way to switch between database connections depending on the request property holding the tenant code.
     * @param defaultManager
     * @param req
     */
    async getOrCreateConnection(defaultManager, req) {
        var _a, _b;
        if (!((_a = this.config.multiTenancy) === null || _a === void 0 ? void 0 : _a.tenantCodeResolver)) {
            throw new Error('Missing tenantCodeResolver from multiTenancy config in medusa-config.');
        }
        const tenantCode = this.config.multiTenancy.tenantCodeResolver(req);
        if (!tenantCode) {
            return defaultManager;
        }
        const tenantRepo = defaultManager.getCustomRepository(__classPrivateFieldGet(this, _TenantService_tenantRepository, "f"));
        const tenant = await tenantRepo.findOne({ where: { code: tenantCode } });
        if (!tenant) {
            throw new Error('Unable to find the tenant from the code found.');
        }
        const connectionManager = (0, typeorm_1.getConnectionManager)();
        if (connectionManager.has(tenant.code)) {
            const connection = await connectionManager.get(tenant.code);
            return Promise.resolve(connection.isConnected ? connection.manager : connection.connect().then((conn) => conn.manager));
        }
        else {
            const db_entities = req.scope.resolve('db_entities');
            await (0, typeorm_1.createConnection)({
                name: tenant.code,
                type: tenant.database_type,
                url: tenant.database_url,
                database: tenant.database_database,
                extra: tenant.database_extra || {},
                entities: db_entities,
                namingStrategy: new naming_strategy_1.ShortenedNamingStrategy(),
                logging: (_b = this.config.projectConfig.database_logging) !== null && _b !== void 0 ? _b : false,
            });
            const connection = await connectionManager.get(tenant.code);
            return Promise.resolve(connection.isConnected ? connection.manager : connection.connect().then((conn) => conn.manager));
        }
    }
};
_TenantService_tenantRepository = new WeakMap();
TenantService.resolutionKey = 'tenantService';
TenantService = __decorate([
    (0, decorators_1.Service)(),
    __metadata("design:paramtypes", [Object, Object])
], TenantService);
exports.TenantService = TenantService;
//# sourceMappingURL=tenant.service.js.map